# HelpfulFunctions.pm
#
# A module with some functions that are used by several other modules.
#
# author:  Max-Gerd Retzlaff <m.retzlaff@gmx.net>,
#          Reyk Floeter <reyk@synack.de>
# date:    $Date: 2002/02/05 20:51:39 $
# version: $Revision: 1.2 $
#
# This application is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version. 
#
# This application is distributed in the hope that it will be useful, 
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with this library; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# 02111 USA.  

package HelpfulFunctions;

use Exporter;
@ISA = ('Exporter');
@EXPORT = ('mdie', 'file_as_string', 'string_to_file', 'unique_array');

sub mdie {
    $error = $_[0];
    $message = $_[1];
    
    # die with or without error. normally you should you mdie(0, ...,
    # to avoid bouncing messages to the sender.
    if($error) {
	die($message."Invoking die().\n");
    } else {
	print($message."Invoking exit().\n");
	exit 0;
    }
}


sub file_as_string {
    my ($target_ref, $filename) = @_;
    
    if ($filename ne '') {
	my $text = "";
	
	{
	    local $/ = undef;
	    open(SOURCE, "< $filename") or 
		mdie(1, "ERROR: Can't open file \"$filename\" for reading.\n");
	    $text = <SOURCE>;
	    close(SOURCE);
	}
	$$target_ref = $text;
	return 0;
    }
    
    return 1;
}

sub string_to_file {
    my ($filename, $text, $octal_mode) = @_;
    
    open(FILE, ">$filename") or 
	mdie(1, "ERROR: Can't open file \"$filename\" for writing.\n");
    print FILE $text;
    close(FILE);

    if ( defined $octal_mode ) {
	chmod($octal_mode, $filename);
    }

    return 0;
}

# returns the unique fields of an array, preserves their order
sub unique_array {
    my @array = @_;

    my %h = ();
    grep(!$h{$_}++,@array);
    @array = keys %h;
    # replace the previous line by "@array = sort keys %h;"
    # if you want a sorted list of the unique fields

    return @array;
}

return 1; # Last executing statement in file must be
          # non-zero, to indicate succesful loading
